using UnityEngine;
using UnityEngine.AI;

public class Enemy : MonoBehaviour
{
    private GameObject playerGameObject;
    private NavMeshAgent navMeshAgent;
    //①Animatorのコンポーネントを保持しておきます。
    private Animator animator;
    //②［Speed］の識別子を保持しておきます。
    private int animIDSpeed;
    //⑦GameManagerを保持します。
    private GameManager gameManager;

    void Awake()
    {
        //NavMeshAgentのコンポーネントを取得します。
        navMeshAgent = GetComponent<NavMeshAgent>();
        //③Animatorのコンポーネントを取得します。
        animator = GetComponent<Animator>();
        //④Animatorのパラメーターの［Speed］の識別子を取得します。
        animIDSpeed = Animator.StringToHash("Speed");
        //⑧ここから
        gameManager = GameObject.FindGameObjectWithTag("GameManager").GetComponent<GameManager>();
        gameManager.OnPlayerGoal.AddListener(OnPlayerGoal);
        //⑧ここまで
        //⑪
        gameManager.OnPlayerDown.AddListener(OnPlayerDown);
    }
    void Start()
    {
        //ターゲットとなるプレイヤーのゲームオブジェクトを取得します。
        playerGameObject = GameObject.FindGameObjectWithTag("Player");
    }
    void Update()
    {
        //⑫ここから
        if (navMeshAgent.isStopped)
        {
            //ナビが停止している場合目的地設定を行わない
            return;
        }
        //⑫ここまで
        //NavMeshAgentに目的地(プレイヤーの座標）を設定します。
        navMeshAgent.destination = playerGameObject.transform.position;
        //⑤［Speed］に移動速度を設定します。
        animator.SetFloat(animIDSpeed, navMeshAgent.speed);
    }
    //⑥ここから
    private void OnFootstep(AnimationEvent animationEvent)
    {
    }
    //⑥ここまで
    //⑨ここから
    private void OnPlayerGoal()
    {
        gameManager.OnPlayerGoal.RemoveListener(OnPlayerGoal);
        Destroy(gameObject);
    }
    //⑨ここまで
    //⑩ここから
    private void OnPlayerDown()
    {
        navMeshAgent.isStopped = true; //ナビを停止
        navMeshAgent.velocity = Vector3.zero; //速度を0にする
        animator.SetFloat(animIDSpeed, 0f); //停止アニメにする
    }
    //⑩ここまで
}