using UnityEngine;
using UnityEngine.InputSystem;// InputValueを使うために必要

public class PlayerController : MonoBehaviour
{
    // 移動速度
    [SerializeField]
    private float moveSpeed = 4.0f;
    // 入力のあった移動ベクトル
    private Vector2 moveAmount;
    // 移動のために追加したRigidbody2Dコンポーネントへの参照
    private Rigidbody2D rigidbody2d;
    // 最初に一度呼び出されます
    private void Awake()
    {
        rigidbody2d = GetComponent<Rigidbody2D>();
    }
    // 入力に変化があったときに呼び出されます
    // Player Inputコンポーネントから、"On"+"アクション名"(先頭大文字)の名前の関数が呼ばれる決まりです
    void OnMove(InputValue value)
    {
        moveAmount = value.Get<Vector2>();
    }
    // 一定間隔で呼び出されるので、rigidbody2dでの移動を行います
    void FixedUpdate()
    {
        // 現在の座標
        Vector2 currentPosition = rigidbody2d.position;
        // 入力されたベクトルから移動量を求める
        // Time.fixedDeltaTimeは前回FixedUpdate()が呼ばれてからの経過時間
        Vector2 deltaPosition = moveAmount * moveSpeed * Time.fixedDeltaTime;
        // 現在の座標に移動量を加算して、新しい座標を計算します
        Vector2 newPosition = currentPosition + deltaPosition;
        // ゲームオブジェクトを新しい座標に移動します
        rigidbody2d.MovePosition(newPosition);
    }
}